#
# spec file for package libhtp
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2
%define lname   %{name}%{sover}
%bcond_without tests
Name:           libhtp
Version:        0.5.49
Release:        1.2
Summary:        HTTP normalizer and parser
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://www.openinfosecfoundation.org/
Source:         https://github.com/OISF/libhtp/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
%if %{with tests}
BuildRequires:  c++_compiler
%endif

%description
The HTP Library is an HTTP normalizer and parser written by Ivan Ristic of Mod Security fame for the OISF. This integrates and provides very advanced processing of HTTP streams for Suricata. The HTP library is required by the engine, but may also be used independently in a range of applications and tools.

%package -n %{lname}
Summary:        Library for HTTP normalizer and parser
Group:          System/Libraries

%description -n %{lname}
The HTP Library is an HTTP normalizer and parser written by Ivan Ristic of Mod Security fame for the OISF. This integrates and provides very advanced processing of HTTP streams for Suricata. The HTP library is required by the engine, but may also be used independently in a range of applications and tools.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1
sed -i 's/\r$//' ChangeLog

%build
autoreconf -fiv
%configure \
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%if %{with tests}
%make_build test
%endif

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}
%license COPYING LICENSE
%doc AUTHORS ChangeLog README
%{_libdir}/libhtp.so.%{sover}
%{_libdir}/libhtp.so.%{sover}.*

%files devel
%license COPYING LICENSE
%{_includedir}/htp
%{_libdir}/libhtp.so
%{_libdir}/pkgconfig/htp.pc

%changelog
* Thu Oct  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.49
  * headers: put a configurable limit on their numbers.
  * htp/table: only fetch element when needed.
  * fuzz: limits the number of transactions.
  * fuzz: improve debug output.
  * fuzz: flush to get full assertion text.
  * request: trim headers values also when there is no name.
* Sat Jun  1 2024 Andreas Stieger <andreas.stieger@gmx.de>
- run tests, spec file tweaks
* Thu Apr 25 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.48
  * decompressor: only take erroneous data on first try
  * autotools: run autoupdate to modernize build system
- Update to version 0.5.47
  * CVE-2024-28871 request: limit probing after missing protocol
    (boo#1222512)
* Mon Feb 19 2024 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.46
  * tx: configurable number of maximum transactions
  * htp: offers possibility to remove transactions
  * headers: limit the size of folded headers
  * request: be more liberal about transfer-encoding value
  * request: continue processing even with invalid headers
  * http0.9: process headers if there are non-space characters
  * htp_util: fix spelling issue
  * src: fix -Wshorten-64-to-32 warnings
  * uri: normalization removes trailing spaces
  * CVE-2024-23837: excessive processing time of HTTP headers can
    lead to a denial of service (boo#1220403)
* Thu Jul 27 2023 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.45
  * log: resist allocation failure
  * support HTTP Bearer authentication
* Tue Jun 20 2023 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.44
  * response: only trim spaces at headers names end
  * response: skips lines before response line
  * headers: log a warning for chunks extension
* Fri Apr 21 2023 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.43
  * htp: do not log content-encoding: none
  * htp: do not error on multiple 100 Continue
  * readme: remove note on libhtp not being stable
  * uri: fix compile warning strict-prototypes
  * bstr: fix compile warning strict-prototypes
  * fuzz_diff: Free the rust test object.
  * github: add CIFuzz workflow
* Tue Nov 29 2022 Michael Ströder <michael@stroeder.com>
- Update to version 0.5.42
  * github: add initial workflow
  * htp: fixes warning about bad delimiter in URI
  * fuzz: fix a null dereference in a diff report
  * htp: fixes warning about integer
* Wed Sep 28 2022 Michael Ströder <michael@stroeder.com>
- Update to version 0.5.41
  * trim white space of invalid folding for first header
  * clear buffered data for body data
  * minor optimization for decompression code
* Mon Jun 27 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.40
  * uri: optionally allows spaces in uri
  * ints: integer handling improvements
  * headers: continue on nul byte
  * headers: consistent trailing space handling
  * list: fix integer overflow
  * util: remove unused htp_utf8_decode
  * fix 100-continue with CL 0
  * lzma: don't do unnecessary realloc
* Thu Nov 18 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.39
  * host: ipv6 address is a valid host
  * util: one char is not always empty line
  * test and fuzz improvements
* Sun Jul  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.38
  * consume empty lines when parsing chunks to avoid quadratic
    complexity.
* Wed Mar  3 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.37
  * support request body decompression
  * several accuracy fixes
  * fuzz improvments
* Fri Dec  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.36
  * fix a http pipelining issue
* Fri Oct  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.35
  * fix memory leak in tunnel traffoc
  * fix case where chunked data causes excessive CPU use
* Sun Sep 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.34
  * support data GAP handling
  * support 100-continue Expect
  * lzma: give more control over settings
* Wed Apr 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.33
  * compression bomb protection
  * memory handling issue found by Oss-Fuzz
  * improve handling of anomalies in traffic
* Sun Dec 15 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.32
  * bug fixes around pipelining
* Tue Sep 24 2019 Martin Hauke <mardnh@gmx.de>
- Udpate to version 0.5.31
  * various improvements related to 'HTTP Evader'
  * various fixes for issues found by oss-fuzz
  * adds optional LZMA decompression
* Tue Mar 26 2019 Martin Hauke <mardnh@gmx.de>
- Correct License
* Thu Mar  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.30
  * array/list handing optimization
  * fuzz targets improvements
- Update to version 0.5.29
  * prepare for oss-fuzz integration
  * fix undefined behavior signed int overflow
  * make status code parsing more robust
* Sun Dec 16 2018 mardnh@gmx.de
- Update to version 0.5.28
  * Fix potential memory leaks
  * Fix string truncation compile warning
* Wed Jul 18 2018 mardnh@gmx.de
- Update to version 0.5.27
  * Folded header field can be parsed as separate if there are
    no data available to peek into [#159]
  * libhtp crash at deal multiple decompression [#158]
  * Fix configure flag handling
  * Fix auth/digist header parsing out of bounds read
* Sun Jun  3 2018 mardnh@gmx.de
- Specfile cleanup
- Update to version 0.5.26
  * allow missing requests [#128, #163]
  * fix memory leak when response line is body [#161]
  * fix build on MinGW [#162]
  * fix gcc7 compiler warnings [#157]
- Update to version 0.5.25
  * underscore in htp_validate_hostname [#149]
  * fix SONAME issue [#151]
  * remove unrelated docbook code from tree [#153]
- Update to version 0.5.24
  * fix HTTP connect handling issue [#150]
* Wed Mar 26 2014 stoppe@gmx.de
- Initial version 0.5.20
